import React from 'react'
import { Modal } from 'react-bootstrap'
import Buttons from '../Curation/Buttons'
import { Player } from 'video-react'
import 'video-react/dist/video-react.css'

const keyring = require('@polkadot/ui-keyring').default
keyring.initKeyring({ isDevelopment: false })

const getUrl = (hash, provider) =>
  `https://${provider}/storage/asset/v0/${keyring.encodeAddress(hash)}`

const PlayerModal = (props) => {
  if (!props.video) return <div />
  const { id, title, description, ipfs } = props.video
  const { addVideoVote, handleChange, me } = props
  const videoSource = getUrl(ipfs, me.provider)
  return (
    <Modal
      size="lg"
      aria-labelledby="contained-modal-title-vcenter"
      centered
      show={props.show}
      onHide={props.onHide}
    >
      <Modal.Header
        className="no-border overflow-hidden bg-dark text-light"
        closeButton
      >
        <Buttons show={me.id} addVideoVote={addVideoVote} id={id} />
        <Modal.Title
          id="contained-modal-title-vcenter"
          title={`[${id}] ${videoSource}`}
          className="text-nowrap overflow-hidden"
        >
          {title}
        </Modal.Title>
      </Modal.Header>
      <Modal.Body className="text-center bg-dark">
        <Player autoPlay playsInline src={videoSource} />
        <SelectProvider handleChange={handleChange} me={me} />
      </Modal.Body>
      <Modal.Footer className="bg-dark text-light">{description}</Modal.Footer>
    </Modal>
  )
}

export default PlayerModal

const SelectProvider = (props: {
  handleChange: () => void,
  me: { providers: { [key: string]: string[] }, provider: string },
}) => {
  const { handleChange, me } = props
  const regions = Object.keys(me.providers)
  return (
    <select
      className="form-control text-center bg-dark text-secondary"
      name="provider"
      value={me.provider}
      onChange={handleChange}
    >
      {regions.map((r) =>
        me.providers[r].map((p) => <option key={p}>{p}</option>)
      )}
    </select>
  )
}
