import React from 'react'
import Video from './Video'
import { ChevronLeft, ChevronRight } from 'react-feather'
import { Button } from 'react-bootstrap'

const Videos = (props: { videos: {}[] }) => {
  const { selectChannel, selectVideo, hideChannel, videos, me } = props
  if (!videos.length) return <div />
  const { channel, page, perPage } = me
  return (
    <div className="d-flex flex-column overflow-hidden w-100 p-2">
      <Channel
        selectChannel={() => selectChannel()}
        show={channel}
        {...videos[0].channel}
      />
      <div className="overflow-auto d-flex flex-wrap justify-content-start mb-5">
        {videos.slice(page * perPage, (page + 1) * perPage).map((video) => (
          <div
            key={video.id}
            className="col-xs-12 col-sm-6 col-md-4 col-lg-3 col-xl-2 bg-dark bg-light"
          >
            <Video
              hideChannel={hideChannel}
              selectChannel={selectChannel}
              selectVideo={selectVideo}
              selectedChannel={channel}
              {...video}
            />
          </div>
        ))}
      </div>
      <Pagination
        selectPage={props.selectPage}
        page={page}
        pages={Math.ceil(videos.length / perPage)}
      />
    </div>
  )
}
export default Videos

const Channel = (props: {
  show: boolean
  handle: string
  description: string
  selectChannel: () => void
}) => {
  const { show, handle, description, selectChannel } = props
  if (!show) return <div />
  return (
    <div>
      <Button variant="dark" className="float-left" onClick={selectChannel}>
        <ChevronLeft />
      </Button>
      <div className="text-light text-center mb-2" onClick={selectChannel}>
        <h2>{handle}</h2>
        <div>{description}</div>
      </div>
    </div>
  )
}

const Pagination = (props: {
  selectPage: (page: number) => void
  page: number
  pages: numbers
}) => {
  const { selectPage, page, pages } = props
  if (!pages || pages <= 1) return <div />
  return (
    <div
      className="w-100 position-fixed d-flex flex-row justify-content-center mt-2"
      style={{ bottom: '0' }}
    >
      <Button
        variant="dark"
        disabled={page <= 0}
        onClick={() => selectPage(page - 1)}
      >
        <ChevronLeft />
      </Button>
      <Button variant="dark" disabled={true}>
        {page + 1}/{pages}
      </Button>
      <Button
        variant="dark"
        disabled={page + 1 > pages}
        onClick={() => selectPage(page + 1)}
      >
        <ChevronRight />
      </Button>
    </div>
  )
}
